/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The sole purpose of this interface is to make it easy for XPCOM
 * object's to hook into JS' toString() when interacting with
 * XPConnect. If you implement this interface and advertize it in the
 * object's classinfo, you'll get automatic mapping from JS'
 * toString() to the toString() method in this interface.
 *
 * XXXjst: This doesn't really belong in dom/public/idl/storage, but
 * it gets to live here until I find a more suitable place.
 */

[scriptable, uuid(2a72e20f-e337-4822-8994-2e35b5550d03)]
interface nsIDOMToString : nsISupports
{
  DOMString toString();
};
