/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

/**
 * SpeechSynthesisGetter
 * http://dvcs.w3.org/hg/speech-api/raw-file/tip/speechapi.html#tts-section
 */

[scriptable, uuid(31e6c818-0279-4948-843c-930043f6bafd)]
interface nsISpeechSynthesisGetter : nsISupports
{
  readonly attribute nsISupports speechSynthesis;
};
